==> eiffelstudio-18.11.10.2592.tar: F_code/C32/in1561.c <==
/*
 * Code for class INSPECT_AS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in1561.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INSPECT_AS}.initialize */
void F2367_29191 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5, EIF_REFERENCE arg6)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(7);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLR(4,arg4);
	RTLR(5,arg5);
	RTLR(6,arg6);
	RTLIU(7);
	
	RTEAA("initialize", 2366, Current, 0, 6, 35133);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg2;
	RTHOOK(3);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg3;
	RTHOOK(4);
	RTAR(Current, arg4);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg4;
	RTHOOK(5);
	if ((EIF_BOOLEAN)(arg5 != NULL)) {
		RTHOOK(6);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg5) + O22390[Dtype(arg5)-2337]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(7);
	if ((EIF_BOOLEAN)(arg6 != NULL)) {
		RTHOOK(8);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg6) + O22390[Dtype(arg6)-2337]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(15);
	RTLE;
	RTEE;
}

/* {INSPECT_AS}.process */
void F2367_29192 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("process", 2366, Current, 0, 1, 35134);
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4572[Dtype(arg1)-304])(RTCW(arg1), Current);
	RTHOOK(2);
	RTEE;
}

/* {INSPECT_AS}.inspect_keyword */
EIF_REFERENCE F2367_29195 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	
	
	RTEAA("inspect_keyword", 2366, Current, 0, 1, 35137);
	RTHOOK(1);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_0_);
	RTHOOK(2);
	RTEE;
	return (EIF_REFERENCE) F2264_28008(Current, arg1, ti4_1);
}

/* {INSPECT_AS}.switch */
EIF_REFERENCE F2367_29198 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {INSPECT_AS}.case_list */
EIF_REFERENCE F2367_29199 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {INSPECT_AS}.else_part */
EIF_REFERENCE F2367_29200 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {INSPECT_AS}.end_keyword */
EIF_REFERENCE F2367_29201 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {INSPECT_AS}.first_token */
EIF_REFERENCE F2367_29202 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("first_token", 2366, Current, 0, 1, 35129);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(arg1 != NULL) && (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_0_) != ((EIF_INTEGER_32) 0L)))) {
		RTHOOK(2);
		RTHOOK(3);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) F2367_29195(Current, arg1);
	} else {
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R21883[Dtype(tr1)-2264])(RTCW(tr1), arg1);
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
}

/* {INSPECT_AS}.last_token */
EIF_REFERENCE F2367_29203 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("last_token", 2366, Current, 0, 1, 35130);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	Result = F2338_28814(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {INSPECT_AS}.is_equivalent */
EIF_BOOLEAN F2367_29204 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("is_equivalent", 2366, Current, 0, 1, 35131);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
	if (F2264_27990(Current, *(EIF_REFERENCE *)(Current + _REFACS_2_), tr1)) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_3_);
		tb1 = F2264_27990(Current, *(EIF_REFERENCE *)(Current + _REFACS_3_), tr1);
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		Result = F2264_27990(Current, *(EIF_REFERENCE *)(Current + _REFACS_1_), tr1);
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit1561 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C32/in1561.c <==
/*
 * Code for class INSPECT_AS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in1561.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INSPECT_AS}.initialize */
void F2371_29201 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5, EIF_REFERENCE arg6)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(7);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLR(4,arg4);
	RTLR(5,arg5);
	RTLR(6,arg6);
	RTLIU(7);
	
	RTEAA("initialize", 2370, Current, 0, 6, 35171);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg2;
	RTHOOK(3);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg3;
	RTHOOK(4);
	RTAR(Current, arg4);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg4;
	RTHOOK(5);
	if ((EIF_BOOLEAN)(arg5 != NULL)) {
		RTHOOK(6);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg5) + O22428[Dtype(arg5)-2344]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(7);
	if ((EIF_BOOLEAN)(arg6 != NULL)) {
		RTHOOK(8);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg6) + O22428[Dtype(arg6)-2344]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(15);
	RTLE;
	RTEE;
}

/* {INSPECT_AS}.process */
void F2371_29202 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("process", 2370, Current, 0, 1, 35157);
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4592[Dtype(RTCW(arg1))-309])(arg1, Current);
	RTHOOK(2);
	RTEE;
}

/* {INSPECT_AS}.inspect_keyword */
EIF_REFERENCE F2371_29205 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("inspect_keyword", 2370, Current, 0, 1, 35160);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_REFERENCE) F2271_28056(Current, arg1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_0_));
}

/* {INSPECT_AS}.first_token */
EIF_REFERENCE F2371_29212 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("first_token", 2370, Current, 0, 1, 35167);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(arg1 != NULL) && (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_0_) != ((EIF_INTEGER_32) 0L)))) {
		RTHOOK(2);
		RTHOOK(3);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) F2371_29205(Current, arg1);
	} else {
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R21921[Dtype(RTCW(tr1))-2271])(tr1, arg1);
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
}

/* {INSPECT_AS}.last_token */
EIF_REFERENCE F2371_29213 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("last_token", 2370, Current, 0, 1, 35168);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	Result = F2345_28862(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {INSPECT_AS}.is_equivalent */
EIF_BOOLEAN F2371_29214 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("is_equivalent", 2370, Current, 0, 1, 35169);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
	if (F2271_28038(Current, *(EIF_REFERENCE *)(Current + _REFACS_2_), tr1)) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_3_);
		tb1 = F2271_28038(Current, *(EIF_REFERENCE *)(Current + _REFACS_3_), tr1);
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		Result = F2271_28038(Current, *(EIF_REFERENCE *)(Current + _REFACS_1_), tr1);
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit1561 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
